/*****************************************************************************
 * Copyright (C) 2014-2019
 *
 * Michiel Broek <mbroek at mbse dot eu>
 *
 * This file is part of BrewCloud
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * BrewCloud is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ThermFerm; see the file COPYING.  If not, write to the Free
 * Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *****************************************************************************/


function createDelElements() {
	$('#eventWindow').jqxWindow({
		theme: theme,
		position: { x: 490, y: 210 },
		width: 300,
		height: 175,
		resizable: false,
		isModal: true,
		modalOpacity: 0.4,
		okButton: $('#delOk'),
		cancelButton: $('#delCancel'),
		initContent: function () {
			$('#delOk').jqxButton({ template: "danger", width: '65px', theme: theme });
			$('#delCancel').jqxButton({ template: "success", width: '65px', theme: theme });
			$('#delCancel').focus();
		}
	});
	$('#eventWindow').jqxWindow('hide');
}


$(document).ready(function () {

	var dataRecord = {};

	function calcTotal(cost, inventory) {

		$('#totval').val(cost * (inventory / 1000));
	}

	var url = "includes/db_inventory_yeasts.php";
	// prepare the data
	var source = {
		datatype: "json",
		cache: false,
		datafields: [
			{ name: 'record', type: 'number' },
			{ name: 'name', type: 'string' },
			{ name: 'type', type: 'int' },
			{ name: 'form', type: 'int' },
			{ name: 'laboratory', type: 'string' },
			{ name: 'product_id', type: 'string' },
			{ name: 'min_temperature', type: 'float' },
			{ name: 'max_temperature', type: 'float' },
			{ name: 'flocculation', type: 'int' },
			{ name: 'attenuation', type: 'float' },
			{ name: 'notes', type: 'string' },
			{ name: 'best_for', type: 'string' },
			{ name: 'max_reuse', type: 'int' },
			{ name: 'inventory', type: 'float' },
			{ name: 'cost', type: 'float' },
			{ name: 'production_date', type: 'string' },
			{ name: 'tht_date', type: 'string' }
		],
		id: 'record',
		url: url,
		deleterow: function (rowid, commit) {
			// synchronize with the server - send delete command
			var data = "delete=true&" + $.param({ record: rowid });
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				type: "POST",
				success: function (data, status, xhr) {
					// delete command is executed.
					commit(true);
				},
				error: function (jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		},
		addrow: function (rowid, rowdata, position, commit) {
			var data = "insert=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				type: "POST",
				success: function (data, status, xhr) {
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		},
		updaterow: function (rowid, rowdata, commit) {
			var data = "update=true&" + $.param(rowdata);
			$.ajax({
				dataType: 'json',
				url: url,
				cache: false,
				data: data,
				type: "POST",
				success: function (data, status, xhr) {
					// update command is executed.
					commit(true);
				},
				error: function(jqXHR, textStatus, errorThrown) {
					commit(false);
				}
			});
		}
	};
	// initialize the input fields.
	$("#name").jqxInput({ theme: theme, width: 640, height: 23 });
	$("#laboratory").jqxInput({ theme: theme, width: 320, height: 23 });
	$("#product_id").jqxInput({ theme: theme, width: 320, height: 23 });
	$("#type").jqxDropDownList({
		theme: theme,
		source: YeastTypeAdapter,
		valueMember: 'id',
		displayMember: 'nl',
		width: 180,
		height: 23,
		autoDropDownHeight: true
	});
	$("#form").jqxDropDownList({
		theme: theme,
		source: YeastFormAdapter,
		valueMember: 'id',
		displayMember: 'nl',
		selectedIndex: 0,
		width: 180,
		height: 23,
		autoDropDownHeight: true
	});
	$("#notes").jqxInput({ theme: theme, width: 800, height: 120 });
	$("#best_for").jqxInput({ theme: theme, width: 320, height: 50 });
	$("#inventory").jqxNumberInput( Spin1dec1 );
	$("#production_date").jqxDateTimeInput( Dateopts );
	$("#min_temperature").jqxNumberInput( YeastT );
	$("#max_temperature").jqxNumberInput( YeastT );
	$("#flocculation").jqxDropDownList({
		theme: theme,
		source: FlocculationAdapter,
		valueMember: 'id',
		displayMember: 'nl',
		width: 180,
		height: 23,
		autoDropDownHeight: true
	});
	$("#attenuation").jqxNumberInput( Perc1dec1 );
	$("#max_reuse").jqxNumberInput( PosInt );
	$("#max_reuse").jqxNumberInput({ max: 10 });
	$("#cost").jqxNumberInput( Spin2dec1 );
	$("#tht_date").jqxDateTimeInput( Dateopts );
	$("#totval").jqxNumberInput( Spin2dec1 );
	$("#totval").jqxNumberInput({ width: 90, readOnly: true, spinButtons: false });

	var dataAdapter = new $.jqx.dataAdapter(source);
	var editrow = -1;
	// initialize jqxGrid
	$("#jqxgrid").jqxGrid({
		width: 1280,
		height: 630,
		source: dataAdapter,
		theme: theme,
		showstatusbar: true,
		localization: getLocalization(),
		renderstatusbar: function (statusbar) {
			var container = $("<div style='overflow: hidden; position: relative; margin: 5px;'></div>");
			var addButton = $("<div style='float: right; margin-right: 15px;'><img style='position: relative; margin-top: 2px;' src='images/add.png'/><span style='margin-left: 4px; position: relative; top: -3px;'>Nieuw</span></div>");
			container.append(addButton);
			statusbar.append(container);
			addButton.jqxButton({ theme: theme, width: 90, height: 20 });
			// add new row.
			addButton.click(function (event) {
				editrow = -1;
				$("#popupWindow").jqxWindow({ position: { x: 110, y: 30 } });
				$("#name").val('');
				$("#laboratory").val('');
				$("#product_id").val('');
				$("#type").val(0);
				$("#form").val(0);
				$("#min_temperature").val(18);
				$("#max_temperature").val(22);
				$("#flocculation").val(0);
				$("#attenuation").val(77);
				$("#notes").val('');
				$("#best_for").val('');
				$("#max_reuse").val(10);
				$("#inventory").val(0);
				$("#cost").val(0);
				$("#production_date").val('');
				$("#tht_date").val('');
				$("#popupWindow").jqxWindow('open');
			});
		},
		filterable: true,
		filtermode: 'excel',
		columns: [
			{ text: 'Laboratorium', datafield: 'laboratory', width: 150 },
			{ text: 'Product ID', datafield: 'product_id', width: 120 },
			{ text: 'Gist naam', datafield: 'name' },
			{ text: 'Type', datafield: 'type', align: 'center', cellsalign: 'center', width: 90,
			  cellsrenderer: function (index, datafield, value, defaultvalue, column, rowdata) {
				return "<div style='margin: 4px;' class='jqx-center-align'>" + YeastTypeData[value].nl + "</div>";
			  }
			},
			{ text: 'Vorm', datafield: 'form', align: 'center', cellsalign: 'center', width: 90,
			  cellsrenderer: function (index, datafield, value, defaultvalue, column, rowdata) {
				return "<div style='margin: 4px;' class='jqx-center-align'>" + YeastFormData[value].nl + "</div>";
			  }
			},
			{ text: 'Vergistingsgraad', datafield: 'attenuation', width: 120, align: 'right', cellsalign: 'right', cellsformat: 'p0' },
			{ text: 'Voor. gr/ml', datafield: 'inventory', width: 100, align: 'right', cellsalign: 'right', cellsformat: 'f1' },
			{ text: 'Prijs kg/l', datafield: 'cost', width: 100, align: 'right', cellsalign: 'right', cellsformat: 'c2' },
			{ text: 'Wijzig', datafield: 'Edit', columntype: 'button', width: 100, align: 'center', cellsrenderer: function () {
				return "Wijzig";
				}, buttonclick: function (row) {
					// open the popup window when the user clicks a button.
					editrow = row;
					$("#popupWindow").jqxWindow({ position: { x: 110, y: 30 } });
					// get the clicked row's data and initialize the input fields.
					dataRecord = $("#jqxgrid").jqxGrid('getrowdata', editrow);
					$("#name").val(dataRecord.name);
					$("#laboratory").val(dataRecord.laboratory);
					$("#product_id").val(dataRecord.product_id);
					$("#type").val(dataRecord.type);
					$("#form").val(dataRecord.form);
					$("#min_temperature").val(dataRecord.min_temperature);
					$("#max_temperature").val(dataRecord.max_temperature);
					$("#flocculation").val(dataRecord.flocculation);
					$("#attenuation").val(dataRecord.attenuation);
					$("#notes").val(dataRecord.notes);
					$("#best_for").val(dataRecord.best_for);
					$("#max_reuse").val(dataRecord.max_reuse);
					$("#inventory").val(dataRecord.inventory);
					$("#cost").val(dataRecord.cost);
					$("#production_date").val(dataRecord.production_date);
					$("#tht_date").val(dataRecord.tht_date);
					calcTotal(dataRecord.cost, dataRecord.inventory);
					// show the popup window.
					$("#popupWindow").jqxWindow('open');
				}
			}
		]
	});

	$("#cost").on('change', function (event) {
		dataRecord.cost = parseFloat(event.args.value);
		calcTotal(dataRecord.cost, dataRecord.inventory);
	});
	$("#inventory").on('change', function (event) {
		dataRecord.inventory = parseFloat(event.args.value);
		calcTotal(dataRecord.cost, dataRecord.inventory);
	});

	// initialize the popup window and buttons.
	$("#popupWindow").jqxWindow({
		width: 1050,
		height: 550,
		resizable: false,
		theme: theme,
		isModal: true,
		autoOpen: false,
		cancelButton: $("#Cancel"),
		modalOpacity: 0.40
	});
	$("#popupWindow").on('open', function () {
		$("#name").jqxInput('selectAll');
	});
	$("#Delete").jqxButton({ template: "danger", width: '90px', theme: theme });
	$("#Delete").click(function () {
		if (editrow >= 0) {
			// Open a popup to confirm this action.
			$('#eventWindow').jqxWindow('open');
			$("#delOk").click(function () {
				var rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
				$("#jqxgrid").jqxGrid('deleterow', rowID);
			});
		}
		$("#popupWindow").jqxWindow('hide');
	});
	$("#Cancel").jqxButton({ template: "primary", width: '90px', theme: theme });
	$("#Save").jqxButton({ template: "success", width: '90px', theme: theme });
	// update the edited row when the user clicks the 'Save' button.
	$("#Save").click(function () {
		var rowID = -1;
		if (editrow >= 0) {
			rowID = $('#jqxgrid').jqxGrid('getrowid', editrow);
		}
		var row = {
			record: rowID,
			name: $("#name").val(),
			type: $("#type").val(),
			form: $("#form").val(),
			laboratory: $("#laboratory").val(),
			product_id: $("#product_id").val(),
			min_temperature: parseInt($("#min_temperature").jqxNumberInput('decimal')),
			max_temperature: parseInt($("#max_temperature").jqxNumberInput('decimal')),
			flocculation: $("#flocculation").val(),
			attenuation: parseFloat($("#attenuation").jqxNumberInput('decimal')),
			notes: $("#notes").val(),
			best_for: $("#best_for").val(),
			max_reuse: parseInt($("#max_reuse").jqxNumberInput('decimal')),
			inventory: parseFloat($("#inventory").jqxNumberInput('decimal')),
			cost: parseFloat($("#cost").jqxNumberInput('decimal')),
			production_date: $("#production_date").val(),
			tht_date: $("#tht_date").val()
		};
		if (editrow >= 0) {
			$('#jqxgrid').jqxGrid('updaterow', rowID, row);
		} else {
			$('#jqxgrid').jqxGrid('addrow', null, row);
		}
		$("#popupWindow").jqxWindow('hide');
		location.reload( true );        // reload ourself.
	});
	createDelElements();
});

